@@ -90,7 +90,6 @@ class Pas:
             if case_flag in ("U", "-"):
                 continue
             arg_type = ArgumentType(case_flag)
-            arg: Argument
             if format_ == CaseInfoFormat.CASE:
                 tid, sdist, sid = int(fields[0]), int(fields[1]), fields[2]
                 assert arg_type != ArgumentType.EXOPHORA
@@ -130,7 +129,7 @@ class Pas:
                         logger.warning(f"surface mismatch ({sentence.sid}): '{surf}' vs '{arg_base_phrase.text}'")
                     pas.add_argument(case, arg_base_phrase)
             else:
-                raise ValueError(f"invalid format: {format_}")
+                raise AssertionError(f"invalid format: {format_}")
         return pas
 
     def get_arguments(
